<?php
/*
Plugin Name: Clym
Plugin URI: https://clym.io
Description: One platform for global privacy needs. Manage Cookies, Consent, Subjects’ Requests, Policies, Terms and prove compliance through consent receipts.
Author: Clym.io
Version: 2.0.2
Author URI: https://www.clym.io/
*/
// Make sure we don't expose any info if called directly
$CLYM_VERSION = '2.0.2';

if (!defined('ABSPATH')) {
    echo 'Hi there!  I\'m just a plugin, not much I can do when called directly.';
    exit;
}

if (!is_admin()) {
    require_once plugin_dir_path(__FILE__) . 'public/clym-public.php';
}

if (is_admin()) {
    $clym = json_decode(get_option('clym'), true);
    if ($clym['clym']['version'] !== $CLYM_VERSION) {
        clym_install();
    }
}

function clym_create_request()
{
    $clym = json_decode(get_option('clym'), true);
    $url = get_site_url();
    $url .= '?clym_request=' . $clym['key'];
    $WP_Http = new WP_Http();
    $WP_Http->request($url);
}

function clym_install()
{
    $clym = file_get_contents(plugins_url('includes/config.json', __FILE__));
    $clymJson = json_decode($clym, true);
    $clymJson['key'] = substr(str_shuffle(str_repeat($key = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ', ceil(64 / strlen($key)))), 1, 64);
    if (!get_option('clym')) {
        update_option('clym', json_encode($clymJson));
    } else {
        $clymBkp = json_decode(get_option('clym'), true);
        $clymJson['have_account'] = $clymBkp['have_account'];
        $clymJson['language']['default'] = $clymBkp['language']['default'];
        $clymJson['meta_tag'] = $clymBkp['meta_tag'];
        $clymJson['widget']['script'] = $clymBkp['widget']['script'];
        $clymJson['widget']['location'] = $clymBkp['widget']['location'];
        update_option('clym', json_encode($clymJson));
    }
}

register_activation_hook(__FILE__, 'clym_install');


function clym_delete()
{
    delete_option('clym');
}

register_uninstall_hook(__FILE__, 'clym_delete');


function clym_admin()
{
    if (!is_admin()) return;
    require_once plugin_dir_path(__FILE__) . 'admin/clym-admin.php';
}

function clym_admin_menu()
{
    $notification = get_option('clym_notification');

    add_menu_page('Clym',
        $notification ? 'Clym <span class="awaiting-mod">' . $notification . '</span>' : 'Clym',
        'manage_options',
        'clym-admin',
        'clym_admin',
        plugins_url('admin/img/icon.png', __FILE__),
        80);
}

add_action('admin_menu', 'clym_admin_menu');


function clym_validate_request($data)
{
    if (!isset($data['key'])) return false;
    $field = $data['key'];
    $value = $data['value'];
    switch ($field) {
        case 'lang':
            {
                $languages = array("en", "ro");
                if (isset($value) && !in_array($value, $languages)) return false;
                break;
            }
        case 'meta_tag':
            {
                if (isset($value) && strlen($value) > 80) return false;
                break;
            }
        case 'widget':
            {
                $location = array("head", "footer");
                if (!isset($value['location'])) return false;
                if (!in_array($value['location'], $location)) return false;
                if (isset($value['script']) && (strpos($value['script'], '<script') === false || strpos($value['script'], '</script>') === false)) return false;
                break;
            }
        case 'plugin':
            {
                if (isset($value)) {
                    $value = str_replace('-', '', $value);
                    if (!preg_match("/^[a-z]+$/", $value)) return false;
                }
                break;
            }
        case 'account':
            {
                return true;
                break;
            }
        default:
            return false;
            break;
    }
    return true;
}

function clym_update_option()
{
    $clym = json_decode(get_option('clym'), true);
    $data = $_POST['data'];
    $status = 'error';
    if (clym_validate_request($data)) {
        $status = 'success';
        $field = $data['key'];
        $value = $data['value'];
        switch ($field) {
            case 'lang':
                {
                    $clym['defaultLanguage'] = $value;
                    update_option('clym', json_encode($clym, JSON_FORCE_OBJECT));
                    break;
                }
            case 'meta_tag':
                {
                    $clym['meta_tag'] = stripslashes_deep($value);
                    $clym['have_account'] = true;
                    update_option('clym', json_encode($clym, JSON_FORCE_OBJECT));
                    break;
                }
            case 'widget':
                {
                    $clym['widget']['script'] = stripslashes_deep($value['script']);
                    $clym['widget']['location'] = $value['location'];
                    $clym['have_account'] = true;
                    update_option('clym', json_encode($clym, JSON_FORCE_OBJECT));
                    clym_create_request();
                    break;
                }
            case 'clym_account':
                {
                    $clym['have_account'] = true;
                    update_option('clym', json_encode($clym, JSON_FORCE_OBJECT));
                }
            default:
                break;
        }
    }
    echo $status;
    wp_die();
}

add_action("wp_ajax_clym_update_option", "clym_update_option");
